'use strict';

Object.defineProperty(exports, "__esModule", {
  value: true
});

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

var _createClass = function () { function defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } } return function (Constructor, protoProps, staticProps) { if (protoProps) defineProperties(Constructor.prototype, protoProps); if (staticProps) defineProperties(Constructor, staticProps); return Constructor; }; }();

var _fs = require('fs');

var _fs2 = _interopRequireDefault(_fs);

var _rfr = require('rfr');

var _rfr2 = _interopRequireDefault(_rfr);

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _fsExtra = require('fs-extra');

var _fsExtra2 = _interopRequireDefault(_fsExtra);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

var debug = (0, _debug2.default)('respondent');

/**
 *
 */

var Respondent = function () {

  /**
   * Create a new Respondent instance.
   *
   * @param {object} options
   * @returns {Respondent}
   * @throws {Error} if a root directory was not specified
   */
  function Respondent(options) {
    _classCallCheck(this, Respondent);

    if (options.rootDir && typeof options.rootDir === 'string') {
      this._rootDir = options.rootDir;

      if (options.env) {
        if (_typeof(options.env) === 'object') {
          process.env = Object.assign({}, process.env, options.env);
        } else {
          throw new Error('{options.env} must be an object');
        }
      }

      this._rfr = (0, _rfr2.default)({ root: this._rootDir });
    } else {
      throw new Error('{options.rootDir} is required');
    }
  }

  /**
   * Retrieve the root path of the config directory.
   *
   * @returns {string}
   */


  _createClass(Respondent, [{
    key: 'getRootDirectory',
    value: function getRootDirectory() {
      return this._rootDir;
    }

    /**
     * Retrieve a value from the specified file.
     *
     * @param {string} valuePath
     * @param {string} defaultValue
     * @returns value
     * @throws {Error} if the config file argument is "index"
     */

  }, {
    key: 'get',
    value: function get(valuePath, defaultValue) {
      var valuePathSplit = valuePath.split('.');
      var value = null;

      var configFile = valuePathSplit[0];

      if (configFile && configFile.toLowerCase() === 'index') {
        throw new Error('The specified config file cannot be used.');
      }

      try {
        debug('Attempting to load a configuration value from ' + configFile);

        var file = this._rfr(configFile);
        value = file;
        for (var i = 1; i < valuePathSplit.length; i++) {
          var exists = false;
          if (i === 1) {
            if (valuePathSplit[i] != null) {
              value = file[valuePathSplit[i]];
              exists = true;
            }
          } else {
            if (value != null) {
              if (valuePathSplit[i] != null) {
                value = value[valuePathSplit[i]];
                exists = true;
              }
            }
          }

          if (exists) {
            debug('Configuration value loaded from \'' + configFile + '\'');
            break;
          }

          if (!exists) {
            debug('\'' + valuePathSplit[0] + '\' doesn\'t exist within \'' + valuePath);
            break;
          }
        }
      } catch (e) {
        debug(e);
        debug('Unable to load file with the name \'' + valuePathSplit[0] + '\'');
      }

      if (value && typeof value === 'string') {
        value = value.toLowerCase() === 'true' || value.toLowerCase() === 'false' ? value.toLowerCase() === 'true' ? true : false : value;
      }

      return value !== undefined && value !== null ? value : defaultValue;
    }

    /**
     * Check if the specified path & value exists.
     *
     * @param {string} valuePath
     * @returns {boolean}
     */

  }, {
    key: 'has',
    value: function has(valuePath) {
      return this.get(valuePath) !== null && this.get(valuePath) !== undefined;
    }
  }]);

  return Respondent;
}();

exports.default = Respondent;
module.exports = exports['default'];